# Conditional for release and snapshot builds. Uncomment for release-builds.
%global rel_build 1

# This is needed, because src-url contains branched part of versioning-scheme.
%global branch 1.23

# Settings used for build from snapshots.
%{!?rel_build:%global commit 4c3a7e168575c4c8a0e235fe9da428759546ba2f}
%{!?rel_build:%global commit_date 20141208}
%{!?rel_build:%global shortcommit %(c=%{commit};echo ${c:0:7})}
%{!?rel_build:%global git_ver git%{commit_date}-%{shortcommit}}
%{!?rel_build:%global git_rel .git%{commit_date}.%{shortcommit}}
%{!?rel_build:%global git_tar %{name}-%{version}-%{git_ver}.tar.xz}

Name:          atril
Version:       %{branch}.0
%if 0%{?rel_build}
Release:       1%{?dist}
%else
Release:       10.1%{?git_rel}%{?dist}
%endif
Summary:       Document viewer
License:       GPLv2+ and LGPLv2+ and MIT
URL:           http://mate-desktop.org

# for downloading the tarball use 'spectool -g -R atril.spec'
# Source for release-builds.
%{?rel_build:Source0:     http://pub.mate-desktop.org/releases/%{branch}/%{name}-%{version}.tar.xz}
# Source for snapshot-builds.
%{!?rel_build:Source0:    http://git.mate-desktop.org/%{name}/snapshot/%{name}-%{commit}.tar.xz#/%{git_tar}}

BuildRequires:  gcc-c++
BuildRequires:  gtk3-devel
BuildRequires:  poppler-glib-devel
BuildRequires:  libXt-devel
BuildRequires:  libsecret-devel
BuildRequires:  libglade2-devel
BuildRequires:  libtiff-devel
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  libspectre-devel
BuildRequires:  desktop-file-utils
BuildRequires:  gobject-introspection-devel
BuildRequires:  mate-common
BuildRequires:  cairo-gobject-devel
BuildRequires:  yelp-tools

# for the xps back-end
BuildRequires:  libgxps-devel
# for the caja properties page
BuildRequires:  caja-devel
# for the dvi back-end
%if 0%{?fedora} >= 24
BuildRequires:  texlive-lib-devel
%else
BuildRequires:  texlive-kpathsea-lib-devel
%endif
# for the djvu back-end
BuildRequires:  djvulibre-devel
# for epub back-end
%if 0%{?fedora} >= 28
BuildRequires:  webkit2gtk3-devel
%else
BuildRequires:  webkitgtk4-devel
%endif

Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
#  fix (#974791)
Requires:       mate-desktop-libs
Requires:       mathjax

%description
Mate-document-viewer is simple document viewer.
It can display and print Portable Document Format (PDF),
PostScript (PS), Encapsulated PostScript (EPS), DVI, DJVU, epub and XPS files.
When supported by the document format, mate-document-viewer
allows searching for text, copying text to the clipboard,
hypertext navigation, table-of-contents bookmarks and editing of forms.


%package libs
Summary: Libraries for the mate-document-viewer

%description libs
This package contains shared libraries needed for mate-document-viewer.


%package devel
Summary: Support for developing back-ends for the mate-document-viewer
Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
This package contains libraries and header files needed for
mate-document-viewer back-ends development.


%package caja
Summary: Mate-document-viewer extension for caja
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: caja

%description caja
This package contains the mate-document-viewer extension for the
caja file manager.
It adds an additional tab called "Document" to the file properties dialog.

%package thumbnailer
Summary: Atril thumbnailer extension for caja
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: caja

%description thumbnailer
This package contains the atril extension for the
caja file manager.


%prep
%if 0%{?rel_build}
%autosetup -p1
%else
%autosetup -n %{name}-%{commit} -p1
%endif

%if 0%{?rel_build}
#NOCONFIGURE=1 ./autogen.sh
%else # 0%{?rel_build}
# needed for git snapshots
NOCONFIGURE=1 ./autogen.sh
%endif # 0%{?rel_build}

%build
%configure \
        --disable-static \
        --disable-schemas-compile \
        --enable-introspection \
        --enable-comics \
        --enable-dvi=yes \
        --enable-djvu=yes \
        --enable-t1lib=no \
        --enable-pixbuf \
        --enable-xps \
        --enable-epub

# remove unused-direct-shlib-dependency
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

make %{?_smp_mflags} V=1


%install
%{make_install}

%find_lang %{name} --with-gnome --all-name

find $RPM_BUILD_ROOT -name '*.la' -exec rm -fv {} ';'


%check
desktop-file-validate ${RPM_BUILD_ROOT}%{_datadir}/applications/atril.desktop


%files -f %{name}.lang
%doc README COPYING NEWS AUTHORS
%{_bindir}/*
%dir %{_datadir}/atril
%{_datadir}/atril/*
%{_datadir}/applications/atril.desktop
%{_datadir}/icons/hicolor/*/apps/atril.*
%{_libexecdir}/atrild
%{_datadir}/dbus-1/services/org.mate.atril.Daemon.service
%{_datadir}/glib-2.0/schemas/org.mate.Atril.gschema.xml
%{_datadir}/metainfo/atril.appdata.xml
%{_mandir}/man1/atril-*.1.*
%{_mandir}/man1/atril.1.*

%files libs
%{_libdir}/libatrilview.so.*
%{_libdir}/libatrildocument.so.*
%{_libdir}/atril/3/backends/
%{_libdir}/girepository-1.0/AtrilDocument-1.5.0.typelib
%{_libdir}/girepository-1.0/AtrilView-1.5.0.typelib

%files caja
%{_libdir}/caja/extensions-2.0/libatril-properties-page.so
%{_datadir}/caja/extensions/libatril-properties-page.caja-extension

%files thumbnailer
%{_datadir}/thumbnailers/atril.thumbnailer

%files devel
%dir %{_includedir}/atril/
%{_includedir}/atril/1.5.0/
%{_libdir}/libatrilview.so
%{_libdir}/libatrildocument.so
%{_libdir}/pkgconfig/atril-view-1.5.0.pc
%{_libdir}/pkgconfig/atril-document-1.5.0.pc
%{_datadir}/gir-1.0/AtrilDocument-1.5.0.gir
%{_datadir}/gir-1.0/AtrilView-1.5.0.gir
%{_datadir}/gtk-doc/html/libatrildocument-1.5.0/
%{_datadir}/gtk-doc/html/libatrilview-1.5.0/
%{_datadir}/gtk-doc/html/atril/


%changelog
* Fri Apr 26 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.0-1
- update to 1.23.0

* Fri Apr 26 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.1-1
- update to 1.22.1

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.0-2
- test https://github.com/mate-desktop/atril/pull/367

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.0-1
- update to 1.22.0

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.1-2
- test https://github.com/mate-desktop/atril/commit/1b95162
- test https://github.com/mate-desktop/atril/pull/347
- test https://github.com/mate-desktop/atril/pull/353
- test https://github.com/mate-desktop/atril/pull/354
- test https://github.com/mate-desktop/atril/pull/360
- test https://github.com/mate-desktop/atril/pull/362

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.1-1
- test 1.21.1

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.0-2
- add BR BuildRequires:  gcc-c++
- test https://github.com/mate-desktop/atril/pull/336
- test https://github.com/mate-desktop/atril/pull/338
- test https://github.com/mate-desktop/atril/pull/339

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.0-1
- test 1.21.0
- test https://github.com/mate-desktop/atril/pull/310
- test new a11y fixes
- use some commits from master
- test use css for view
- test https://github.com/mate-desktop/atril/pull/313
- test local deprecation fix
- use webkit2gtk3-devel for f28
- test https://github.com/mate-desktop/atril/pull/324

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.20.0-2
- test https://github.com/mate-desktop/atril/pull/294

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.20.0-1
- update to 1.20.0 release
- drop desktop-database rpm scriptlet
- drop GSettings Schema rpm scriptlet
- drop IconCache Schema rpm scriptlet
- switch to using autosetup

* Mon Nov 27 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.6-1
- test 1.19.6
- fixes https://bugzilla.redhat.com/show_bug.cgi?id=1525313

* Mon Nov 27 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.5-2
- test https://github.com/mate-desktop/atril/pull/288
- try fix https://bugzilla.redhat.com/show_bug.cgi?id=1525313

* Mon Nov 27 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.5-1
- update to 1.19.5

* Thu Nov 23 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.4-2
- fix rhbz (#1513826)

* Sat Oct 14 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.4-1
- update to 1.19.4

* Wed Sep 06 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.3-1
- update to 1.19.3 release

* Tue Aug 29 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.2-2
- test local layout branch

* Tue Aug 29 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.2-1
- update to 1.19.2 release

* Tue Aug 15 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.1-2
- test branch dev-more-backports, needs to tested with touchpad
- use https://github.com/mate-desktop/atril/commit/2f1f970
- test https://github.com/mate-desktop/atril/pull/277
- test local introspection fixes
- test local annotation fixes

* Tue Aug 15 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.1-1
- update to 1.19.1 release
- test branch dev-more-backports, needs to tested with touchpad
- use https://github.com/mate-desktop/atril/commit/2f1f970
- test https://github.com/mate-desktop/atril/pull/277

* Wed May 10 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.0-2
- test https://github.com/mate-desktop/atril/commit/f4291fd
- test https://github.com/mate-desktop/atril/pull/260
- test https://github.com/mate-desktop/atril/pull/262
- test https://github.com/mate-desktop/atril/commit/2dd0cfd
- test https://github.com/mate-desktop/atril/pull/268, merged
- test https://github.com/mate-desktop/atril/pull/273, annontation improvements
- test branch dev-more-backports, needs to tested with touchpad
- test dev-sidbar-thumbnails, fixes https://github.com/mate-desktop/atril/issues/255

* Wed May 10 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.0-1
- update to 1.19.0 release

* Tue Mar 14 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.18.0-1
- update to 1.18.0 release
- test deprecation fixes

* Fri Mar 10 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.1-2
- test deprecation fixes

* Fri Mar 10 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.1-1
- update to 1.17.1 release
- test https://github.com/mate-desktop/atril/pull/207

* Sat Jan 28 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.0-5
- test deprecation fixes
- test https://github.com/mate-desktop/atril/pull/207

* Sat Jan 28 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.0-4
- test https://github.com/mate-desktop/atril/pull/242

* Sat Jan 28 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.0-3
- test https://github.com/mate-desktop/atril/pull/240

* Sat Jan 28 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.0-2
- fix running under gnome-wayland session

* Tue Dec 06 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.0-1
- update 1.17.0 release

* Sat Sep 17 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.16.0-1
- test 1.16.0 release

* Thu Jun 30 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.3-1
- test 1.15.3

* Thu Jun 30 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.2-2
- test switch to GtkAbout

* Thu Jun 30 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.2-1
- test 1.15.2

* Thu Jun 30 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.1-2
- test new patches

* Thu Jun 30 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.1-1
- update to 1.15.1 release

* Sat May 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.0-1
- test 1.15.0 release
- switch to gtk3

* Sat May 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.1-11
- update to 1.14.1 release
- apply dev-page-cache branch, fixes rhbz (#1258640)

* Sun May 15 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.0-12
- fix for rhbz (#1303999)
- use https://github.com/mate-desktop/atril/commit/e9ff838
- use https://github.com/mate-desktop/atril/pull/201

* Wed Apr 06 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.0-11
- update to 1.14.0 release

* Sun Feb 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.1-12
- add css name EggToolbarEditor

* Sun Feb 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.1-11
- update to 1.13.1 release

* Mon Jan 25 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.0-12
- test, add style class atril-window

* Mon Jan 25 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.0-11
- update to 1.13.0 release

* Mon Dec 28 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.2-12
- update webkit version logic for epel7

* Sun Dec 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.2-11
- update to 1.12.2 release

* Wed Dec 02 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-11
- update to 1.12.1 release
- removed upstreamed patch

* Fri Nov 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-12
- fix-dvi-regression, https://github.com/mate-desktop/atril/issues/164

* Sat Oct 31 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-11
- update to 1.12.0 release

* Wed Oct 14 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0-11
- update to 1.11.0 release
- drop runtime require mate-icon-theme
- add runtime require mathjax for epub

* Mon Aug 31 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-11
- update to 1.10.2 release

* Mon Jul 13 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.1-11
- update to 1.10.1 release
- remove non needed atril-1.9.0_webkit-gtk3.patch

* Tue May 05 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-11
- update to 1.10.0 release

* Sat Apr 04 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.90-11
- update to 1.9.90 release

* Tue Jan 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.2-10
- bump version to more than ten

* Thu Jan 22 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.2-1
- update to 1.9.2 release

* Thu Dec 11 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.1-1
- update to 1.9.1 release

* Sat Oct 11 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.1-0.1.git20141208.4c3a7e1
- test, introspection
- do not build t1lib anymore

* Sat Oct 11 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.1-0.1.git20141204.1b877bf
- test epub patch, latest git

* Sat Oct 11 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-2
- test epub patch

* Sat Oct 11 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-1
- test update to 1.9.0
- Add epub support (part of GSoC 2014).
- Use MateAboutDialog from libmate-desktop
- remove upstreamed patches
- add configure patch
- build for GTK3

* Sat Oct 11 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.1-2
- enable thumbnailer support and use a -thumbnailer subpackage for it
- fix rhbz (#1150875)

* Mon Sep 29 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.1-1
- update to 1.8.1 release

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Aug 15 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.0-7
- disable thumbnailer

* Fri Aug 01 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.0-6
- rebuild to obsolete mate-document-viewer correctly

* Tue Jul 22 2014 Kalev Lember <kalevlember@gmail.com> - 1.8.0-5
- Rebuilt for gobject-introspection 1.41.4

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Apr 21 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.0-3
- fix rhbz (#1082143)

* Wed Mar 19 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.0-2
- fix rhbz (#999912)
- use better conditionals for obsoleting mate-document-viewer

* Wed Mar 05 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.8.0-1
- Update to 1.8.0

* Wed Feb 19 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.90-1
- update to 1.7.90
- no need of autoreconf anymore

* Mon Feb 10 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.2.1
- update to 1.7.2 release
- add autoreconf to fix building

* Fri Jan 24 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.1-1
- update to 1.7.1 release
- add gtk-doc dir for release builds

* Wed Jan 22 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.1-0.1.git20140122.26539f8
- update to git snapshot from 2014.01.22

* Wed Dec 18 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.0-0.2.git20131120.26539f8
- make Maintainers life easier and use better git snapshot usage, Thanks to Björn Esser
- use modern 'make install' macro
- limit obsoletes/provides

* Sat Dec 14 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.0-0.1.git26539f8
- rename to atril
- use 1.7 git snaphot
- fix rpm scriptlets

* Sat Oct 12 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-6
- fix rhbz (#1005519)

* Thu Aug 08 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-5
- rebuild for mate-desktop package split
- add runtime require mate-desktop-libs, fix #974791
- change caja subpackage requires
- remove -libs subpackage requires to main package
- add icon cache scriplets for internal icons
- use autoreconf instead of autogen

* Mon Aug 05 2013 Rex Dieter <rdieter@fedoraproject.org> - 1.6.1-4
- fix deps so main pkg isn't multilib'd
- workaround libtool breakage
- .spec cleanup

* Sat Aug 03 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-3
- fix obsoleting old -data subpackage

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Aug 02 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-1
- update to 1.6.1
- remove -data subpackage
- remove NOCONFIGURE=1 ./autogen.sh line

* Sun Jun 16 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-6
- add require mate-desktop, fix #974791

* Mon May 13 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-5
- remove isa tag from -data subpackage requires

* Sat May 11 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-4
- remove gsettings convert file
- create -data noarch subpackage
- move docs in -data subpackage
- move help dir in -data subpackage
- move locale in -data subpackage

* Fri May 10 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-3
- remove -dvi, -djvu, -xps subpackages and move the libs to -libs subpackage
- add Requires: %%{name}%%{?_isa} = %%{version}-%%{release} to -libs subpackage
- remove sed commands for desktop file
- add hicolor-icon-theme require
- fix last changelog date
- rename atril to mate-document-viewer in summarys and descriptions
- to avoid rpmlint warnings
- rename evince to mate-document-viewer in description
- update description
- fix mixed-use-of-spaces-and-tabs in spec file
- move additional doc files to valid doc dir

* Thu May 09 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-2
- use libmate-keyring-devel as BR instead of mate-keyring-devel
- fix spelling-error in %%description of -devel subpackage
- fix gsettings schema rpm scriptlets

* Wed Apr 03 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-1
- update to 1.6.0

* Thu Mar 21 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.5.0-2
- initial build for fedora

* Fri Nov 16 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.5.0-1
- build against official fedora
- update to 1.5.0
- remove scrollkeeper BR
- remove mate-conf schema directory
- remove upstreamed mate-document-viewer_change_ev_api_version.patch
- remove epoch

* Mon Nov 05 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1:1.4.0-0102
- add epoch
- add desktop-file-validate
- remove (noreplace) from schema files

* Sat Oct 06 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-0101
- improve and review spec file
- own include dir
- add mate-document-viewer_change_ev_api_version.patch
- fix license information
- add ChangeLog
- fix description
- fix unused-direct-shlib-dependency
- fix scriplet section

* Mon Aug 27 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-0100
- build for f18

* Tue Jul 17 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-2
- rebuild for f17 and f18

* Tue Jul 17 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-1
- update to 1.4.0

* Tue Jun 19 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.2.1-3
- test build

* Tue Jun 19 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.2.1-2
- Silence rpm scriptlet output in fc17

* Thu Mar 15 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.2.1-1
- update to 1.2.1

* Mon Mar 12 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.2.0-1
- update to 1.2.0

* Tue Jan 17 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.1.1-2
- rebuild for enable builds for .i686

* Tue Jan 17 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.1.1-1
- updated to 1.1.1 version

* Wed Jan 04 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.1.0-1
- atril.spec based on evince-2.32.0-4.fc14 spec

